import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions(
      {required this.context,
      required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false}) {
    switch (animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
    }
  }

  void _normalTransition() {
    final Route route = MaterialPageRoute(builder: (context) => child);

    (replacement) ? _pushReplacementNavigator(route) : _pushNavigator(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => child,
        transitionDuration: duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
              opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                  CurvedAnimation(parent: animation, curve: Curves.easeInOut)),
              child: this.child);
        });

    (replacement) ? _pushReplacementNavigator(route) : _pushNavigator(route);
  }

  void _pushNavigator(Route route) => Navigator.push(context, route);
  void _pushReplacementNavigator(Route route) =>
      Navigator.pushReplacement(context, route);
}
